#[non_exhaustive]pub struct MarkerNotFoundPredicate;Expand description
A predicate that allows forking providers to search for a provider that supports a particular data marker.
This is normally used implicitly by ForkByMarkerProvider.